This is an automated email from the ASF dual-hosted git repository.

yuxia pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/fluss.git


The following commit(s) were added to refs/heads/main by this push:
     new 168a092b9 [iceberg] Bump iceberg version to 1.10.0 (#2008)
168a092b9 is described below

commit 168a092b99017af1f628dcdf2d114c664403f981
Author: Eduard Tudenhoefner <[email protected]>
AuthorDate: Fri Nov 28 08:14:53 2025 +0100

    [iceberg] Bump iceberg version to 1.10.0 (#2008)
---
 docker/quickstart-flink/prepare_build.sh           | 12 ++++----
 fluss-filesystems/fluss-fs-gs/pom.xml              |  4 +++
 .../src/main/resources/META-INF/NOTICE             | 36 ++++++++++++----------
 pom.xml                                            |  2 +-
 .../integrate-data-lakes/iceberg.md                | 12 ++++----
 5 files changed, 36 insertions(+), 30 deletions(-)

diff --git a/fluss-filesystems/fluss-fs-gs/pom.xml 
b/fluss-filesystems/fluss-fs-gs/pom.xml
index 6df6ec783..4993a63fe 100644
--- a/fluss-filesystems/fluss-fs-gs/pom.xml
+++ b/fluss-filesystems/fluss-fs-gs/pom.xml
@@ -73,6 +73,10 @@
                     <groupId>com.sun.jersey</groupId>
                     <artifactId>jersey-json</artifactId>
                 </exclusion>
+                <exclusion>
+                    <groupId>com.github.pjfanning</groupId>
+                    <artifactId>jersey-json</artifactId>
+                </exclusion>
                 <exclusion>
                     <groupId>com.sun.jersey</groupId>
                     <artifactId>jersey-server</artifactId>
diff --git a/fluss-lake/fluss-lake-iceberg/src/main/resources/META-INF/NOTICE 
b/fluss-lake/fluss-lake-iceberg/src/main/resources/META-INF/NOTICE
index 20bae701e..331e7324f 100644
--- a/fluss-lake/fluss-lake-iceberg/src/main/resources/META-INF/NOTICE
+++ b/fluss-lake/fluss-lake-iceberg/src/main/resources/META-INF/NOTICE
@@ -6,28 +6,30 @@ The Apache Software Foundation (http://www.apache.org/).
 
 This project bundles the following dependencies under the Apache Software 
License 2.0 (http://www.apache.org/licenses/LICENSE-2.0.txt)
 
-- org.apache.iceberg:iceberg-core:1.9.1
-- org.apache.iceberg:iceberg-api:1.9.1
-- org.apache.iceberg:iceberg-bundled-guava:1.9.1
-- org.apache.iceberg:iceberg-common:1.9.1
-- org.apache.iceberg:iceberg-data:1.9.1
-- org.apache.iceberg:iceberg-orc:1.9.1
-- org.apache.iceberg:iceberg-parquet:1.9.1
+- org.apache.iceberg:iceberg-core:1.10.0
+- org.apache.iceberg:iceberg-api:1.10.0
+- org.apache.iceberg:iceberg-bundled-guava:1.10.0
+- org.apache.iceberg:iceberg-common:1.10.0
+- org.apache.iceberg:iceberg-data:1.10.0
+- org.apache.iceberg:iceberg-orc:1.10.0
+- org.apache.iceberg:iceberg-parquet:1.10.0
 - org.apache.avro:avro:1.12.0
-- org.apache.parquet:parquet-avro:1.15.2
-- org.apache.parquet:parquet-column:1.15.2
-- org.apache.parquet:parquet-encoding:1.15.2
-- org.apache.parquet:parquet-hadoop:1.15.2
-- org.apache.parquet:parquet-format-structures:1.15.2
-- org.apache.parquet:parquet-jackson:1.15.2
-- org.apache.parquet:parquet-common:1.15.2
-- org.apache.orc:orc-core:nohive:1.9.5
-- org.apache.orc:orc-shims:1.9.5
+- org.apache.parquet:parquet-avro:1.16.0
+- org.apache.parquet:parquet-column:1.16.0
+- org.apache.parquet:parquet-encoding:1.16.0
+- org.apache.parquet:parquet-hadoop:1.16.0
+- org.apache.parquet:parquet-format-structures:1.16.0
+- org.apache.parquet:parquet-jackson:1.16.0
+- org.apache.parquet:parquet-common:1.16.0
+- org.apache.parquet:parquet-variant:1.16.0
+- org.apache.orc:orc-core:nohive:1.9.7
+- org.apache.orc:orc-shims:1.9.7
 - org.apache.commons:commons-lang3:3.18.0
 - org.apache.commons:commons-compress:1.24.0
-- org.apache.httpcomponents.client5:httpclient5:5.4.3
+- org.apache.httpcomponents.client5:httpclient5:5.5
 - org.apache.httpcomponents.core5:httpcore5:5.3.4
 - org.apache.httpcomponents.core5:httpcore5-h2:5.3.4
+- org.locationtech.jts:jts-core:1.20.0
 - com.fasterxml.jackson.core:jackson-core:2.15.3
 - com.fasterxml.jackson.core:jackson-databind:2.15.3
 - com.fasterxml.jackson.core:jackson-annotations:2.15.3
diff --git a/pom.xml b/pom.xml
index 2d6efef30..247040141 100644
--- a/pom.xml
+++ b/pom.xml
@@ -89,7 +89,7 @@
         <netty.version>4.1.104.Final</netty.version>
         <arrow.version>15.0.0</arrow.version>
         <paimon.version>1.3.1</paimon.version>
-        <iceberg.version>1.9.1</iceberg.version>
+        <iceberg.version>1.10.0</iceberg.version>
 
         <fluss.hadoop.version>3.4.0</fluss.hadoop.version>
         <frocksdb.version>6.20.3-ververica-2.0</frocksdb.version>
diff --git a/website/docs/streaming-lakehouse/integrate-data-lakes/iceberg.md 
b/website/docs/streaming-lakehouse/integrate-data-lakes/iceberg.md
index 4e299ebe1..6e0d62b26 100644
--- a/website/docs/streaming-lakehouse/integrate-data-lakes/iceberg.md
+++ b/website/docs/streaming-lakehouse/integrate-data-lakes/iceberg.md
@@ -31,7 +31,7 @@ datalake.iceberg.warehouse: /tmp/iceberg
 
 Fluss processes Iceberg configurations by stripping the `datalake.iceberg.` 
prefix and uses the stripped configurations (without the prefix 
`datalake.iceberg.`) to initialize the Iceberg catalog.
 
-This approach enables passing custom configurations for Iceberg catalog 
initialization. Check out the [Iceberg Catalog 
Properties](https://iceberg.apache.org/docs/1.9.1/configuration/#catalog-properties)
 for more details on available catalog configurations.
+This approach enables passing custom configurations for Iceberg catalog 
initialization. Check out the [Iceberg Catalog 
Properties](https://iceberg.apache.org/docs/1.10.0/configuration/#catalog-properties)
 for more details on available catalog configurations.
 
 #### Supported Catalog Types
 
@@ -93,11 +93,11 @@ Fluss only bundles catalog implementations included in the 
`iceberg-core` module
 
 ##### 3. Version Compatibility
 
-The Iceberg version that Fluss bundles is based on `1.9.1`. Please ensure the 
JARs you add are compatible with `Iceberg-1.9.1`.
+The Iceberg version that Fluss bundles is based on `1.10.0`. Please ensure the 
JARs you add are compatible with `Iceberg-1.10.0`.
 
 #### Important Notes
 
-- Ensure all JAR files are compatible with Iceberg 1.9.1
+- Ensure all JAR files are compatible with Iceberg 1.10.0
 - If using an existing Hadoop environment, it's recommended to use the 
`HADOOP_CLASSPATH` environment variable
 - Configuration changes take effect after restarting the Fluss service
 
@@ -171,8 +171,8 @@ Put the JARs required by your Iceberg FileIO into 
`${FLINK_HOME}/lib`:
 **S3 FileIO:**
 ```bash
 # Required JARs for S3 FileIO
-iceberg-aws-1.9.1.jar
-iceberg-aws-bundle-1.9.1.jar
+iceberg-aws-1.10.0.jar
+iceberg-aws-bundle-1.10.0.jar
 failsafe-3.3.2.jar
 ```
 
@@ -190,7 +190,7 @@ When following the [Start Datalake Tiering 
Service](maintenance/tiered-storage/l
 
 #### Important Notes
 
-- Ensure all JAR files are compatible with Iceberg 1.9.1
+- Ensure all JAR files are compatible with Iceberg 1.10.0
 - Verify that all required dependencies are in the `${FLINK_HOME}/lib` 
directory
 - Check the Flink job logs for any missing dependency errors
 - Restart the Flink cluster after adding new JAR files

Reply via email to
diff --git a/docker/quickstart-flink/prepare_build.sh 
b/docker/quickstart-flink/prepare_build.sh
index 222cf35f3..dfd440fb3 100755
--- a/docker/quickstart-flink/prepare_build.sh
+++ b/docker/quickstart-flink/prepare_build.sh
@@ -170,12 +170,12 @@ main() {
     # Iceberg Support
     log_info "Downloading Iceberg connector JARs..."
 
     # Download iceberg-flink-runtime for Flink 1.20 (version 1.9.1)
     download_jar \
-        
"https://repo1.maven.org/maven2/org/apache/iceberg/iceberg-flink-runtime-1.20/1.9.1/iceberg-flink-runtime-1.20-1.9.1.jar";
 \
-        "./lib/iceberg-flink-runtime-1.20-1.9.1.jar" \
+        
"https://repo1.maven.org/maven2/org/apache/iceberg/iceberg-flink-runtime-1.20/1.10.0/iceberg-flink-runtime-1.20-1.10.0.jar";
 \
+        "./lib/iceberg-flink-runtime-1.20-1.10.0.jar" \
         "" \
-        "iceberg-flink-runtime-1.20-1.9.1"
+        "iceberg-flink-runtime-1.20-1.10.0"
 
 
     # Prepare lake tiering JAR
@@ -201,7 +201,7 @@ verify_jars() {
         "flink-faker-0.5.3.jar"
         "hadoop-apache-3.3.5-2.jar"
         "paimon-flink-1.20-1.2.0.jar"
-        "iceberg-flink-runtime-1.20-1.9.1.jar"
+        "iceberg-flink-runtime-1.20-1.10.0.jar"
     )
 
     local opt_jars=(
@@ -250,7 +250,7 @@ show_summary() {
     echo "  ✓ Fluss Flink 1.20 connector"
     echo "  ✓ Fluss Lake Paimon connector"
     echo "  ✓ Fluss Lake Iceberg connector"
-    echo "  ✓ Iceberg Flink runtime 1.20 (v1.9.1)"
+    echo "  ✓ Iceberg Flink runtime 1.20 (v1.10.0)"
     echo "  ✓ Paimon Flink 1.20 (v1.2.0)"
     echo "  ✓ Hadoop Apache (v3.3.5-2)"
     echo "  ✓ Flink Faker (v0.5.3)"
@@ -170,12 +170,12 @@ main() {
     log_info "Downloading Iceberg connector JARs..."
 
-    # Download iceberg-flink-runtime for Flink 1.20 (version 1.9.1)
+    # Download iceberg-flink-runtime for Flink 1.20 (version 1.10.0)
     download_jar \